==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ServiceEndpointPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ServiceEndpointPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Service End point policy resource.
 * @property contextualServiceEndpointPolicies A collection of contextual service endpoint policy.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property location Resource location.
 * @property serviceAlias The alias indicating if the policy belongs to a service
 * @property serviceEndpointPolicyDefinitions A collection of service endpoint policy definitions of the service endpoint policy.
 * @property tags Resource tags.
 */
public data class ServiceEndpointPolicyArgs(
    public val contextualServiceEndpointPolicies: Output<List<String>>? = null,
    public val etag: Output<String>? = null,
    public val id: Output<String>? = null,
    public val location: Output<String>? = null,
    public val serviceAlias: Output<String>? = null,
    public val serviceEndpointPolicyDefinitions: Output<List<ServiceEndpointPolicyDefinitionArgs>>? =
        null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ServiceEndpointPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ServiceEndpointPolicyArgs =
        com.pulumi.azurenative.network.inputs.ServiceEndpointPolicyArgs.builder()
            .contextualServiceEndpointPolicies(
                contextualServiceEndpointPolicies?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            )
            .etag(etag?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .serviceAlias(serviceAlias?.applyValue({ args0 -> args0 }))
            .serviceEndpointPolicyDefinitions(
                serviceEndpointPolicyDefinitions?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [ServiceEndpointPolicyArgs].
 */
@PulumiTagMarker
public class ServiceEndpointPolicyArgsBuilder internal constructor() {
    private var contextualServiceEndpointPolicies: Output<List<String>>? = null

    private var etag: Output<String>? = null

    private var id: Output<String>? = null

    private var location: Output<String>? = null

    private var serviceAlias: Output<String>? = null

    private var serviceEndpointPolicyDefinitions: Output<List<ServiceEndpointPolicyDefinitionArgs>>? =
        null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value A collection of contextual service endpoint policy.
     */
    @JvmName("fevkixfrjudblplc")
    public suspend fun contextualServiceEndpointPolicies(`value`: Output<List<String>>) {
        this.contextualServiceEndpointPolicies = value
    }

    @JvmName("cpflhwmqxyrdpbub")
    public suspend fun contextualServiceEndpointPolicies(vararg values: Output<String>) {
        this.contextualServiceEndpointPolicies = Output.all(values.asList())
    }

    /**
     * @param values A collection of contextual service endpoint policy.
     */
    @JvmName("urmshrbgwracteeb")
    public suspend fun contextualServiceEndpointPolicies(values: List<Output<String>>) {
        this.contextualServiceEndpointPolicies = Output.all(values)
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("xarvxludmcwiaefj")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("bysalyrpvwdadngw")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Resource location.
     */
    @JvmName("nwxusqfuxmawdsop")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The alias indicating if the policy belongs to a service
     */
    @JvmName("nnvyvaocbivcdqui")
    public suspend fun serviceAlias(`value`: Output<String>) {
        this.serviceAlias = value
    }

    /**
     * @param value A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("krkyferppqhupkem")
    public suspend
    fun serviceEndpointPolicyDefinitions(`value`: Output<List<ServiceEndpointPolicyDefinitionArgs>>) {
        this.serviceEndpointPolicyDefinitions = value
    }

    @JvmName("jbjnvldglhvvrtfn")
    public suspend fun serviceEndpointPolicyDefinitions(
        vararg
        values: Output<ServiceEndpointPolicyDefinitionArgs>,
    ) {
        this.serviceEndpointPolicyDefinitions = Output.all(values.asList())
    }

    /**
     * @param values A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("eyarqmausyqemxhb")
    public suspend
    fun serviceEndpointPolicyDefinitions(values: List<Output<ServiceEndpointPolicyDefinitionArgs>>) {
        this.serviceEndpointPolicyDefinitions = Output.all(values)
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("xvbqajhdgneanbsu")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value A collection of contextual service endpoint policy.
     */
    @JvmName("blwrhscxdikcncoo")
    public suspend fun contextualServiceEndpointPolicies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contextualServiceEndpointPolicies = mapped
    }

    /**
     * @param values A collection of contextual service endpoint policy.
     */
    @JvmName("btyhntqhgcblhjcm")
    public suspend fun contextualServiceEndpointPolicies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contextualServiceEndpointPolicies = mapped
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("tgqwfkrrntjgiahs")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("fcobhsqsnitaoljq")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Resource location.
     */
    @JvmName("avcljrnouqlpmhaw")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The alias indicating if the policy belongs to a service
     */
    @JvmName("gpaapvyhwtywmpoy")
    public suspend fun serviceAlias(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceAlias = mapped
    }

    /**
     * @param value A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("nhbgtamrhocqixlc")
    public suspend
    fun serviceEndpointPolicyDefinitions(`value`: List<ServiceEndpointPolicyDefinitionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param argument A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("aynxdimomjjtbqoy")
    public suspend
    fun serviceEndpointPolicyDefinitions(argument: List<suspend ServiceEndpointPolicyDefinitionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ServiceEndpointPolicyDefinitionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param argument A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("jrjdivaqafnwjjoa")
    public suspend fun serviceEndpointPolicyDefinitions(
        vararg
        argument: suspend ServiceEndpointPolicyDefinitionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ServiceEndpointPolicyDefinitionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param argument A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("atwwfvmcnmctctlq")
    public suspend
    fun serviceEndpointPolicyDefinitions(argument: suspend ServiceEndpointPolicyDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ServiceEndpointPolicyDefinitionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param values A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("kcntkootbfkxfaee")
    public suspend fun serviceEndpointPolicyDefinitions(
        vararg
        values: ServiceEndpointPolicyDefinitionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("kvhjgglwistxvasp")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("rhniipvcakngxlgk")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): ServiceEndpointPolicyArgs = ServiceEndpointPolicyArgs(
        contextualServiceEndpointPolicies = contextualServiceEndpointPolicies,
        etag = etag,
        id = id,
        location = location,
        serviceAlias = serviceAlias,
        serviceEndpointPolicyDefinitions = serviceEndpointPolicyDefinitions,
        tags = tags,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ServiceEndpointPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ServiceEndpointPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Service End point policy resource.
 * @property contextualServiceEndpointPolicies A collection of contextual service endpoint policy.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property location Resource location.
 * @property serviceAlias The alias indicating if the policy belongs to a service
 * @property serviceEndpointPolicyDefinitions A collection of service endpoint policy definitions of the service endpoint policy.
 * @property tags Resource tags.
 */
public data class ServiceEndpointPolicyArgs(
    public val contextualServiceEndpointPolicies: Output<List<String>>? = null,
    public val etag: Output<String>? = null,
    public val id: Output<String>? = null,
    public val location: Output<String>? = null,
    public val serviceAlias: Output<String>? = null,
    public val serviceEndpointPolicyDefinitions: Output<List<ServiceEndpointPolicyDefinitionArgs>>? =
        null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ServiceEndpointPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ServiceEndpointPolicyArgs =
        com.pulumi.azurenative.network.inputs.ServiceEndpointPolicyArgs.builder()
            .contextualServiceEndpointPolicies(
                contextualServiceEndpointPolicies?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            )
            .etag(etag?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .serviceAlias(serviceAlias?.applyValue({ args0 -> args0 }))
            .serviceEndpointPolicyDefinitions(
                serviceEndpointPolicyDefinitions?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [ServiceEndpointPolicyArgs].
 */
@PulumiTagMarker
public class ServiceEndpointPolicyArgsBuilder internal constructor() {
    private var contextualServiceEndpointPolicies: Output<List<String>>? = null

    private var etag: Output<String>? = null

    private var id: Output<String>? = null

    private var location: Output<String>? = null

    private var serviceAlias: Output<String>? = null

    private var serviceEndpointPolicyDefinitions: Output<List<ServiceEndpointPolicyDefinitionArgs>>? =
        null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value A collection of contextual service endpoint policy.
     */
    @JvmName("odcpkylsqaiawyfn")
    public suspend fun contextualServiceEndpointPolicies(`value`: Output<List<String>>) {
        this.contextualServiceEndpointPolicies = value
    }

    @JvmName("stboyjepqxmkpyto")
    public suspend fun contextualServiceEndpointPolicies(vararg values: Output<String>) {
        this.contextualServiceEndpointPolicies = Output.all(values.asList())
    }

    /**
     * @param values A collection of contextual service endpoint policy.
     */
    @JvmName("mbcvflmxltegvstr")
    public suspend fun contextualServiceEndpointPolicies(values: List<Output<String>>) {
        this.contextualServiceEndpointPolicies = Output.all(values)
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("cvjnohkrxftqpltk")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("sixefcwpvuknkxhw")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Resource location.
     */
    @JvmName("fvjgvakcobawtvyt")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The alias indicating if the policy belongs to a service
     */
    @JvmName("cdurvdeesdslykfe")
    public suspend fun serviceAlias(`value`: Output<String>) {
        this.serviceAlias = value
    }

    /**
     * @param value A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("gknpnndhfqguqqoc")
    public suspend
    fun serviceEndpointPolicyDefinitions(`value`: Output<List<ServiceEndpointPolicyDefinitionArgs>>) {
        this.serviceEndpointPolicyDefinitions = value
    }

    @JvmName("nmtfindsnyencicx")
    public suspend fun serviceEndpointPolicyDefinitions(
        vararg
        values: Output<ServiceEndpointPolicyDefinitionArgs>,
    ) {
        this.serviceEndpointPolicyDefinitions = Output.all(values.asList())
    }

    /**
     * @param values A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("cvnbxjmemvoloqqo")
    public suspend
    fun serviceEndpointPolicyDefinitions(values: List<Output<ServiceEndpointPolicyDefinitionArgs>>) {
        this.serviceEndpointPolicyDefinitions = Output.all(values)
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("woidsdjhytuucqdc")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value A collection of contextual service endpoint policy.
     */
    @JvmName("wogverwgbbwvjxxc")
    public suspend fun contextualServiceEndpointPolicies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contextualServiceEndpointPolicies = mapped
    }

    /**
     * @param values A collection of contextual service endpoint policy.
     */
    @JvmName("jxbnhdajlahuvduw")
    public suspend fun contextualServiceEndpointPolicies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contextualServiceEndpointPolicies = mapped
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("qmctcgsvcapefvoa")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("nekkiyjquqqjlnop")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Resource location.
     */
    @JvmName("pwmktnuwbjdtqgbj")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The alias indicating if the policy belongs to a service
     */
    @JvmName("mbaxyvfaifmtftcl")
    public suspend fun serviceAlias(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceAlias = mapped
    }

    /**
     * @param value A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("uliqvmfrsqbwyiaq")
    public suspend
    fun serviceEndpointPolicyDefinitions(`value`: List<ServiceEndpointPolicyDefinitionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param argument A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("rdxvwvotvomehyow")
    public suspend
    fun serviceEndpointPolicyDefinitions(argument: List<suspend ServiceEndpointPolicyDefinitionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ServiceEndpointPolicyDefinitionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param argument A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("ftwjbobbjlhyydje")
    public suspend fun serviceEndpointPolicyDefinitions(
        vararg
        argument: suspend ServiceEndpointPolicyDefinitionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ServiceEndpointPolicyDefinitionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param argument A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("vmckrndvofdeeuvb")
    public suspend
    fun serviceEndpointPolicyDefinitions(argument: suspend ServiceEndpointPolicyDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ServiceEndpointPolicyDefinitionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param values A collection of service endpoint policy definitions of the service endpoint policy.
     */
    @JvmName("esnuqcxbkmqhdidn")
    public suspend fun serviceEndpointPolicyDefinitions(
        vararg
        values: ServiceEndpointPolicyDefinitionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.serviceEndpointPolicyDefinitions = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("sfpckrulutwcraoj")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("ssnixmbkpncnbgwf")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): ServiceEndpointPolicyArgs = ServiceEndpointPolicyArgs(
        contextualServiceEndpointPolicies = contextualServiceEndpointPolicies,
        etag = etag,
        id = id,
        location = location,
        serviceAlias = serviceAlias,
        serviceEndpointPolicyDefinitions = serviceEndpointPolicyDefinitions,
        tags = tags,
    )
}
